Module: Devise::Webauthn::UrlHelpers
- Defined in:
- lib/devise/webauthn/url_helpers.rb
Overview
Create url helpers to be used with resource/scope configuration. Acts as proxies to the generated routes created by devise. Resource param can be a string or symbol, a class, or an instance object. Example using a :user resource:
new_passkey_path(:user) => new_user_passkey_path
passkeys_path(:user) => user_passkeys_path
passkey_path(:user) => user_passkey_path
Those helpers are included by default to ActionController::Base.
In case you want to add such helpers to another class, you can do that as long as this new class includes both url_helpers and mounted_helpers. Example:
include Rails.application.routes.url_helpers
include Rails.application.routes.mounted_helpers